# Image Multi Thresholding

## How to install

Install from the test PyPI repository by running:

```
python3 -m pip install image-multithresholding
```

After that, you'll be able to import any files from the `image_multi_thresholding` package inside your Python projects.

## Acknowledgments

The authors want to thank Lucas Dimoulas for his interesting comments and suggestions.

## Citing Image Multithresholding package

Please cite the Image Multi Thresholding package as follows:

```
@software{leon2022image,
    author       = {Joaquin Leon and Andrea Rey},
    title        = {Image Multithresholding: A Python package},
    month        = jul,
    year         = 2022,
    publisher    = {PyPi},
    version      = {latest},
    url          = {https://github.com/image-multithresholding/Image-multithresholding}
}
```